@@ -311,11 +311,9 @@ void SKGMonthlyPluginWidget::onPutNewHotStuff()
 
         dialog->setUploadFile(zipFileName);
         dialog->setUploadName(templat);
-#ifdef SKGKDE46ENABLED
         dialog->setPreviewImageFile(0, KUrl(preview1));
         dialog->setPreviewImageFile(1, KUrl(preview2));
         dialog->setPreviewImageFile(2, KUrl(preview3));
-#endif
         dialog->setDescription(i18nc("Default description for a monthly report template", "My favorite template"));
         dialog->exec();
         delete dialog;
@@ -340,7 +338,7 @@ QString SKGMonthlyPluginWidget::getReport()
         SKGReport* rep = getDocument()->getReport();
         if (rep) {
             rep->setMonth(getMonth());
-            err = rep->getReportFormTemplate(rep, ui.kTemplate->itemData(ui.kTemplate->currentIndex()).toString(), html);
+            err = rep->getReportFromTemplate(rep, ui.kTemplate->itemData(ui.kTemplate->currentIndex()).toString(), html);
 
             delete rep;
         }
