@@ -33,13 +33,13 @@ class KAction;
 class SKGPrintPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGPrintPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGPrintPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -84,12 +84,12 @@ public:
     virtual int getOrder() const;
 
 private Q_SLOTS:
-    void actionPrint();
-    void actionPrintPreview();
+    void onPrint();
+    void onPrintPreview();
     void print(QPrinter* iPrinter);
 
 private:
-    Q_DISABLE_COPY(SKGPrintPlugin);
+    Q_DISABLE_COPY(SKGPrintPlugin)
 
     SKGDocument* m_currentDocument;
     KAction* m_printAction;
