@@ -36,13 +36,13 @@ class SKGMainPanel;
 class SKGUndoRedoPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGUndoRedoPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGUndoRedoPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -122,7 +122,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -131,17 +131,18 @@ public:
      * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
      *   @see SKGError
      */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution);
 
 private Q_SLOTS:
-    void actionUndoSave();
-    void actionUndo();
-    void actionRedo();
+    void onUndoSave();
+    void onUndo();
+    void onRedo();
+    void onClearHistory();
 
     void onShowUndoMenu();
     void onShowRedoMenu();
 private:
-    Q_DISABLE_COPY(SKGUndoRedoPlugin);
+    Q_DISABLE_COPY(SKGUndoRedoPlugin)
 
     KAction* m_undoSaveAction;
     KToolBarPopupAction* m_undoAction;
