@@ -73,6 +73,8 @@ SKGImportPluginCsv::SKGImportPluginCsv(QObject* iImporter, const QVariantList& i
     m_parameters["columns_positions"] = "";
 
     m_parameters["mode_csv_unit"] = 'N';
+
+    m_parameters["date_format"] = "";
 }
 
 SKGImportPluginCsv::~SKGImportPluginCsv()
@@ -158,7 +160,7 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
         QFile file(m_importer->getLocalFileName());
         if (!file.open(QIODevice::ReadOnly)) {
             err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
@@ -209,7 +211,7 @@ SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
         QFile file(m_importer->getLocalFileName());
         if (!file.open(QIODevice::ReadOnly)) {
             err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
@@ -277,7 +279,7 @@ SKGError SKGImportPluginCsv::importFile()
             QFile file(m_importer->getLocalFileName());
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                 err.setReturnCode(ERR_INVALIDARG);
-                err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+                err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
             } else {
                 QTextStream stream(&file);
                 if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
@@ -340,13 +342,14 @@ SKGError SKGImportPluginCsv::importFile()
                 file.close();
 
                 //Select dateformat
-                QString dateFormat = SKGServices::getDateFormat(dates);
+                QString dateFormat = m_parameters["date_format"];
+                if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates); //Automatic detection
                 if (!err && dateFormat.isEmpty()) {
                     err.setReturnCode(ERR_FAIL);
                     err.setMessage(i18nc("Error message",  "Date format not supported"));
                 }
                 if (!err)
-                    err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName(), m_importer->getCodec(), dateFormat));
+                    err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
 
                 //Step 2 done
                 if (!err) err = m_importer->getDocument()->stepForward(2);
@@ -580,7 +583,7 @@ SKGError SKGImportPluginCsv::importFile()
                             err = currentOperation.setProperty(propertiesAtt.at(p) , propertiesVal.at(p));
                         }
 
-                        if (!err && i % 20 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
@@ -620,7 +623,7 @@ SKGError SKGImportPluginCsv::importFile()
 bool SKGImportPluginCsv::isExportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginCsv::isExportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "CSV");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "CSV");
 }
 
 SKGError SKGImportPluginCsv::exportFile()
@@ -630,10 +633,10 @@ SKGError SKGImportPluginCsv::exportFile()
     SKGTRACEINRC(2, "SKGImportCsv::exportFile", err);
 
     //Open file
-    KSaveFile file(m_importer->getLocalFileName());
+    KSaveFile file(m_importer->getLocalFileName(false));
     if (!file.open()) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName()));
+        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
     } else {
         QTextStream out(&file);
         if (!m_importer->getCodec().isEmpty()) out.setCodec(m_importer->getCodec().toAscii().constData());
@@ -667,7 +670,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), 3);
         if (!err) {
             //File name is the name of the unit
-            QFileInfo fInfo(m_importer->getFileName());
+            QFileInfo fInfo(m_importer->getFileName().path());
             QString unitName = fInfo.baseName();
 
             //Default mapping
@@ -684,7 +687,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                 QFile file(m_importer->getLocalFileName());
                 if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                     err.setReturnCode(ERR_INVALIDARG);
-                    err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+                    err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
                 } else {
                     QTextStream stream(&file);
                     if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
@@ -722,7 +725,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                         err.setMessage(i18nc("Error message",  "Date format not supported"));
                     }
                     if (!err)
-                        err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName(), m_importer->getCodec(), dateFormat));
+                        err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
 
                     //Step 2 done
                     if (!err) err = m_importer->getDocument()->stepForward(2);
