@@ -67,7 +67,7 @@ bool SKGImportPluginGnc::isImportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginCsv::isImportPossible");
     if (!m_importer) return true;
-    QString extension = QFileInfo(m_importer->getFileName()).suffix().toUpper();
+    QString extension = m_importer->getFileNameExtension();
     return (extension == "UNCOMPRESSED" || extension == "GNUCASH" || extension == "GNC");
 }
 
@@ -81,7 +81,7 @@ SKGError SKGImportPluginGnc::importFile()
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
     if (!file->open(QIODevice::ReadOnly)) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
     } else {
         QDomDocument doc;
 
@@ -96,7 +96,7 @@ SKGError SKGImportPluginGnc::importFile()
             err.setReturnCode(ERR_ABORT);
             err.setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
 
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName()));
+            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
         } else {
             //Get root
             QDomElement docElem = doc.documentElement();
@@ -107,7 +107,7 @@ SKGError SKGImportPluginGnc::importFile()
                 book = docElem;
             }
             if (book.isNull()) {
-                err = SKGError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName()));
+                err = SKGError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
             } else {
                 QMap<QString, SKGUnitObject> mapUnitIdUnit;
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "GNC"), 6);
@@ -460,7 +460,7 @@ SKGError SKGImportPluginGnc::importFile()
                                 }
                             }
 
-                            if (!err && i % 100 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                            if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
 
                             if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                         }
