@@ -29,7 +29,7 @@
 class SKGImportPluginJson : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -65,7 +65,7 @@ public:
 
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginJson);
+    Q_DISABLE_COPY(SKGImportPluginJson)
 };
 
 #endif // SKGIMPORTPLUGINJSON_H
