@@ -55,7 +55,7 @@ SKGImportPluginMT940::~SKGImportPluginMT940()
 bool SKGImportPluginMT940::isImportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginMT940::isImportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "MT940");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "MT940");
 }
 
 SKGError SKGImportPluginMT940::importFile()
@@ -72,7 +72,7 @@ SKGError SKGImportPluginMT940::importFile()
             QFile file(m_importer->getLocalFileName());
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                 err.setReturnCode(ERR_INVALIDARG);
-                err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+                err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
             } else {
 
                 //Read lines
