@@ -57,7 +57,7 @@ SKGImportPluginOfx::~SKGImportPluginOfx()
 bool SKGImportPluginOfx::isImportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginOfx::isImportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "OFX" || QFileInfo(m_importer->getFileName()).suffix().toUpper() == "QFX");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "OFX" || m_importer->getFileNameExtension() == "QFX");
 }
 
 SKGError SKGImportPluginOfx::importFile()
@@ -69,7 +69,7 @@ SKGError SKGImportPluginOfx::importFile()
 
     if (!QFile(m_importer->getLocalFileName()).exists()) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
     }
 
     if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX"));
@@ -85,7 +85,7 @@ SKGError SKGImportPluginOfx::importFile()
             ofx_set_transaction_cb(ctx, SKGImportPluginOfx::ofxTransactionCallback, m_importer);
             //ofx_set_security_cb(ctx, ofxSecurityCallback, this);
             int rc = libofx_proc_file(ctx, m_importer->getLocalFileName().toUtf8(), AUTODETECT);
-            if (rc)  err = SKGError(ERR_FAIL, i18nc("Error message",  "Import OFX file '%1' failed", m_importer->getFileName()));
+            if (rc)  err = SKGError(ERR_FAIL, i18nc("Error message",  "Import OFX file '%1' failed", m_importer->getFileName().prettyUrl()));
             if (!err) err = SKGImportPluginOfx::m_ofxError;
             {
                 //This is an option ==> no error management
