@@ -52,6 +52,8 @@ SKGImportPluginQif::SKGImportPluginQif(QObject* iImporter , const QVariantList&
 {
     SKGTRACEIN(10, "SKGImportPluginQif::SKGImportPluginQif");
     Q_UNUSED(iArg);
+
+    m_parameters["date_format"] = "";
 }
 
 SKGImportPluginQif::~SKGImportPluginQif()
@@ -89,7 +91,7 @@ SKGError SKGImportPluginQif::importFile()
         QFile file(m_importer->getLocalFileName());
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
@@ -135,13 +137,14 @@ SKGError SKGImportPluginQif::importFile()
             file.close();
 
             //Select dateformat
-            QString dateFormat = SKGServices::getDateFormat(dates);
+            QString dateFormat = m_parameters["date_format"];
+            if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates); //Automatic detection
             if (dateFormat.isEmpty()) {
                 err.setReturnCode(ERR_FAIL);
                 err.setMessage(i18nc("Error message",  "Date format not supported"));
             }
             if (!err)
-                err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName(), m_importer->getCodec(), dateFormat));
+                err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
 
             //Step 2 done
             if (!err) err = m_importer->getDocument()->stepForward(2);
@@ -669,8 +672,8 @@ SKGError SKGImportPluginQif::importFile()
                                     if (!err) {
                                         //Is the created operation already existing as a transfer?
                                         double qua = SKGServices::stringToDouble(opOrigin.getAttribute("f_QUANTITY"));
-                                        QString wc = "t_import_id='QIF TRANSFER-" % transferAccount % "' AND t_ACCOUNT='" % accountOrigin.getName() %
-                                                     "' AND  f_QUANTITY=" % SKGServices::doubleToString(qua) %
+                                        QString wc = "t_import_id='QIF TRANSFER-" % SKGServices::stringToSqlString(transferAccount) % "' AND t_ACCOUNT='" % SKGServices::stringToSqlString(accountOrigin.getName()) %
+                                                     "' AND (ABS(f_CURRENTAMOUNT-(" % SKGServices::doubleToString(opOrigin.getCurrentAmount()) % "))<0.0001 OR f_QUANTITY=" % SKGServices::doubleToString(qua) % ")"
                                                      " AND ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(QDateTime(opOrigin.getDate())) % "'))<1"
                                                      " ORDER BY ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(QDateTime(opOrigin.getDate())) % "')) ASC";
                                         SKGObjectBase::SKGListSKGObjectBase obs;
@@ -682,19 +685,31 @@ SKGError SKGImportPluginQif::importFile()
                                             if (!err) err = opOrigin.save();
                                             if (!err) err = firstOne.mergeAttribute(opOrigin);
 
-                                            if (!err) err = currentOperation.setStatus(SKGOperationObject::NONE); //To be sure we can delete it
-                                            if (!err) err = currentOperation.remove(false, true);
+                                            SKGObjectBase::SKGListSKGObjectBase list;
+                                            if (!err) err = currentOperation.getGroupedOperations(list);
+                                            foreach(const SKGObjectBase & o, list) {
+                                                SKGOperationObject op(o);
+                                                if (!err) err = op.setStatus(SKGOperationObject::NONE); //To be sure we can delete it
+                                                if (!err) err = op.remove(false, true);
+                                            }
                                         } else {
                                             //Create target account if needed
                                             SKGAccountObject accountTransfer(m_importer->getDocument());
-                                            accountTransfer.setName(transferAccount);
-                                            if (!accountTransfer.exist()) {
-                                                //The account is created in the same bank by default
-                                                SKGBankObject bankOrigin;
-                                                if (!err) err = accountOrigin.getBank(bankOrigin);
-                                                if (!err) err = accountTransfer.setBank(bankOrigin);
-                                                if (!err) err = accountTransfer.save();
-                                            } else err = accountTransfer.load();
+                                            if (m_accountCache.contains(transferAccount)) {
+                                                accountTransfer = m_accountCache[transferAccount];
+                                            } else {
+
+                                                accountTransfer.setName(transferAccount);
+                                                if (!accountTransfer.exist()) {
+                                                    //The account is created in the same bank by default
+                                                    SKGBankObject bankOrigin;
+                                                    if (!err) err = accountOrigin.getBank(bankOrigin);
+                                                    if (!err) err = accountTransfer.setBank(bankOrigin);
+                                                    if (!err) err = accountTransfer.save(false, true);
+                                                } else err = accountTransfer.load();
+
+                                                m_accountCache[transferAccount] = accountTransfer;
+                                            }
 
                                             //Create operation
                                             SKGUnitObject unit;
@@ -725,7 +740,7 @@ SKGError SKGImportPluginQif::importFile()
                             //Check Sum($)=T for incident 214462
                             QString checkOperationAmountString = SKGServices::doubleToString(checkOperationAmount);
                             QString checkSuboperationsAmountString = SKGServices::doubleToString(checkSuboperationsAmount);
-                            if (checkOperationAmount != 0 && checkSuboperationsAmount != 0 && checkOperationAmountString != checkSuboperationsAmountString) {
+                            if (!err && checkOperationAmount != 0 && checkSuboperationsAmount != 0 && checkOperationAmountString != checkSuboperationsAmountString) {
                                 err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Warning: The total amount of the operation (%1) is different to the sum of the sub-operations (%2).", checkOperationAmountString, checkSuboperationsAmountString));
                             }
 
@@ -745,7 +760,7 @@ SKGError SKGImportPluginQif::importFile()
                         }
                     }
 
-                    if (!err && i % 100 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
@@ -770,7 +785,7 @@ SKGError SKGImportPluginQif::importFile()
 bool SKGImportPluginQif::isExportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginQif::isExportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "QIF");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "QIF");
 }
 
 SKGError SKGImportPluginQif::exportFile()
@@ -780,10 +795,10 @@ SKGError SKGImportPluginQif::exportFile()
     SKGTRACEINRC(2, "SKGImportQif::exportFile", err);
 
     //Open file
-    KSaveFile file(m_importer->getLocalFileName());
+    KSaveFile file(m_importer->getLocalFileName(false));
     if (!file.open()) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName()));
+        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
     } else {
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
