@@ -61,7 +61,7 @@ SKGImportPluginSkg::~SKGImportPluginSkg()
 bool SKGImportPluginSkg::isImportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginSkg::isImportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "SKG" || QFileInfo(m_importer->getFileName()).suffix().toUpper() == "SQLITE");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "SKG" || m_importer->getFileNameExtension() == "SQLITE");
 }
 
 SKGError SKGImportPluginSkg::importFile()
@@ -71,7 +71,7 @@ SKGError SKGImportPluginSkg::importFile()
     SKGTRACEINRC(2, "SKGImportPluginSkg::importFile", err);
 
     SKGDocumentBank docOrigin;
-    err = docOrigin.load(m_importer->getFileName(), m_parameters["password"]);
+    err = docOrigin.load(m_importer->getLocalFileName(), m_parameters["password"]);
     if (!err) {
         QMap<QString, SKGObjectBase> mapOriginNew;
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "SKG"), 10);
@@ -347,7 +347,7 @@ SKGError SKGImportPluginSkg::importFile()
                     }
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
 
-                    if (!err && i % 100 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
                 }
 
                 if (!err) err = m_importer->getDocument()->endTransaction(true);
@@ -484,20 +484,21 @@ SKGError SKGImportPluginSkg::exportFile()
     }
 
     //Copy file to file
-    QFile::remove(m_importer->getLocalFileName());
-    if (QFileInfo(m_importer->getLocalFileName()).suffix().toUpper() == "SQLITE") {
-        if (!KIO::NetAccess::file_copy(tempFile, m_importer->getLocalFileName())) {
+    QString file = m_importer->getLocalFileName(false);
+    QFile::remove(file);
+    if (QFileInfo(file).suffix().toUpper() == "SQLITE") {
+        if (!KIO::NetAccess::file_copy(tempFile, file)) {
             //Set error message
             err.setReturnCode(ERR_FAIL);
-            err.setMessage(i18nc("An error message", "Creation file '%1' failed", m_importer->getLocalFileName()));
+            err.setMessage(i18nc("An error message", "Creation file '%1' failed", file));
         }
     } else {
-        err = SKGServices::cryptFile(tempFile, m_importer->getLocalFileName(), "", true, m_importer->getDocument()->getDocumentHeader());
+        err = SKGServices::cryptFile(tempFile, file, "", true, m_importer->getDocument()->getDocumentHeader());
         if (!err) {
             SKGDocumentBank doc;
-            err = doc.load(m_importer->getLocalFileName());
+            err = doc.load(file);
             if (!err) err = doc.removeAllTransactions();
-            if (!err) err = doc.save();
+            if (!err) err = doc.saveAs(file, true);
         }
     }
 
