@@ -29,7 +29,7 @@
 class SKGImportPluginXml : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -65,7 +65,7 @@ public:
 
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginXml);
+    Q_DISABLE_COPY(SKGImportPluginXml)
 };
 
 #endif // SKGIMPORTPLUGINXML_H
