@@ -31,17 +31,15 @@
 
 #include <QDomDocument>
 
-
 SKGAccountBoardWidget::SKGAccountBoardWidget(SKGDocument* iDocument)
-    : SKGWidget(iDocument), m_refreshNeeded(true)
+    : SKGBoardWidget(iDocument, i18nc("Title of a dashboard widget", "Accounts")), m_refreshNeeded(true)
 {
     SKGTRACEIN(10, "SKGAccountBoardWidget::SKGAccountBoardWidget");
 
-    ui.setupUi(this);
-
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
+    //menu
     m_menuFavorite = new KAction(KIcon("bookmarks"), i18nc("Display only favorite accounts", "Highlighted only"), this);
     m_menuFavorite->setCheckable(true);
     m_menuFavorite->setChecked(false);
@@ -108,10 +106,13 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(SKGDocument* iDocument)
     connect(m_menuOther, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuOther);
 
+    m_label = new QLabel();
+    setMainWidget(m_label);
+
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
-    connect(ui.kLabel, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
+    connect(m_label, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 }
 
 SKGAccountBoardWidget::~SKGAccountBoardWidget()
@@ -195,7 +196,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
             if (!err) {
                 QString html;
                 if (!exist) {
-                    html = "<html><body>" % i18nc("Message, do not translate URL (sk://...)", "First, you have to create at least one account<br>from <a href=\"skg://Skrooge_bank_plugin/\">\"Bank and Account\"</a> page or <a href=\"skg://import_operation\">import</a> operations.") % "</body></html>";
+                    html = "<html><body>" % i18nc("Message, do not translate URL", "First, you have to create at least one account<br>from <a href=\"%1\">\"Bank and Account\"</a> page or <a href=\"%2\">import</a> operations.", "skg://Skrooge_bank_plugin", "skg://import_operation") % "</body></html>";
                 } else {
                     //Build where clause
                     QString wc;
@@ -271,7 +272,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                 account.getUnit(unitAccount);
                                 QString unitAccountSymbol = unitAccount.getSymbol();
 
-                                html += QString("<tr><td><a href=\"skg://Skrooge_operation_plugin/?account=" % KUrl::encode_string(name) % "\">") % SKGServices::stringToHtml(name) % "</a></td>"
+                                html += QString("<tr><td><a href=\"skg://Skrooge_operation_plugin/?account=" % SKGServices::encodeForUrl(name) % "\">") % SKGServices::stringToHtml(name) % "</a></td>"
                                         "<td align=\"right\">";
 
                                 if (!unitAccountSymbol.isEmpty() && primary.Symbol != unitAccountSymbol) {
@@ -294,14 +295,13 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                     "<td align=\"right\"><b>" % doc->formatMoney(sumTypeV1, primary) % "</b></td>"
                                     "</tr>";
                         }
-                        html += "<tr><td><b><a href=\"skg://Skrooge_operation_plugin/?account=" % KUrl::encode_string(i18nc("Noun, all items in a list", "All")) %
-                                "\">" % SKGServices::stringToHtml(i18nc("Noun, the numerical total of a sum of values", "Total")) % "</a></b></td>"
+                        html += "<tr><td><b>" % SKGServices::stringToHtml(i18nc("Noun, the numerical total of a sum of values", "Total")) % "</b></td>"
                                 "<td align=\"right\"><b>" % doc->formatMoney(sumV1, primary) % "</b></td>"
                                 "</tr>";
                         html += "</table></body></html>";
                     }
                 }
-                ui.kLabel->setText(html);
+                m_label->setText(html);
             }
         }
     }
