@@ -81,7 +81,7 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument, const QStringList
 
     KAction* deleteUnusedCategoriesAction = new KAction(KIcon(icon(), NULL, overlaydelete), i18nc("Verb", "Delete unused categories"), this);
     connect(deleteUnusedCategoriesAction, SIGNAL(triggered(bool)), SLOT(deleteUnusedCategories()));
-    registerGlobalAction("edit_delete_unused_categories", deleteUnusedCategoriesAction);
+    registerGlobalAction("clean_delete_unused_categories", deleteUnusedCategoriesAction);
     return true;
 }
 
@@ -103,17 +103,33 @@ QString SKGCategoriesPlugin::getDashboardWidgetTitle(int iIndex)
 SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
 {
     SKGTRACEIN(1, "SKGCategoriesPlugin::getDashboardWidget");
-    if (iIndex == 0) return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                getDashboardWidgetTitle(iIndex),
-                                KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/categories_month_table.html"),
-                                QStringList() << "v_operation_consolidated", true);
-    else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                     getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/categories_variations.html"),
-                                     QStringList() << "v_operation_consolidated", true);
+    if (iIndex == 0)  {
+        SKGHtmlBoardWidget* w = new SKGHtmlBoardWidget(m_currentBankDocument,
+                getDashboardWidgetTitle(iIndex),
+                KStandardDirs().findResource("data", "skrooge/html/default/categories_month_table.html"),
+                QStringList() << "v_operation_consolidated", true);
+
+        QStringList overlayopen;
+        overlayopen.push_back("skg_open");
+        KAction* open = new KAction(KIcon("view-investment", NULL, overlayopen), i18nc("Verb", "Open report..."), w);
+        connect(open, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+        QString url = QString("skg://skrooge_report_plugin/?grouped=Y&transfers=Y&tracked=Y&expenses=Y&incomes=N&lines2=t_REALCATEGORY&currentPage=-1&mode=0&interval=2&period=2&nbLevelLines=1") %
+                      "&tableAndGraphState.graphMode=2&tableAndGraphState.allPositive=N&tableAndGraphState.sortColumn=1&tableAndGraphState.show=graph;table&columns=" % SKGServices::encodeForUrl("#NOTHING#");
+        open->setData(url);
+
+        QAction* sep = new QAction(this);
+        sep->setSeparator(true);
+        w->insertAction(1, sep);
+
+        w->insertAction(1, open);
+        return w;
+    } else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                       getDashboardWidgetTitle(iIndex),
+                                       KStandardDirs().findResource("data", "skrooge/html/default/categories_variations.html"),
+                                       QStringList() << "v_operation_consolidated", true);
     else if (iIndex == 2) return new SKGHtmlBoardWidget(m_currentBankDocument,
                                      getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/budget_table.html"),
+                                     KStandardDirs().findResource("data", "skrooge/html/default/budget_table.html"),
                                      QStringList() << "v_budget", true);
     return NULL;
 }
@@ -214,6 +230,7 @@ QStringList SKGCategoriesPlugin::tips() const
 {
     QStringList output;
     output.push_back(i18nc("Description of a tips", "<p>... categories can be reorganized by drag & drop.</p>"));
+    output.push_back(i18nc("Description of a tips", "<p>... if you delete a category, all operations affected by this category will be associated to its parent category.</p>"));
     return output;
 }
 
@@ -243,7 +260,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused categories"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing categories that have no operations."));
             QStringList autoCorrections;
-            autoCorrections.push_back("skg://edit_delete_unused_categories");
+            autoCorrections.push_back("skg://clean_delete_unused_categories");
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -299,10 +316,10 @@ void SKGCategoriesPlugin::deleteUnusedCategories() const
 
         QStringList categoriesUsed;
         err = m_currentBankDocument->getDistinctValues("category", "t_fullname", "t_fullname in ("
-                "SELECT category.t_fullname FROM category, suboperation WHERE suboperation.r_category_id=category.id UNION "
-                "SELECT category.t_fullname FROM category, budget WHERE budget.rc_category_id=category.id UNION "
-                "SELECT category.t_fullname FROM category, budgetrule WHERE budgetrule.rc_category_id=category.id UNION "
-                "SELECT category.t_fullname FROM category, budgetrule WHERE budgetrule.rc_category_id_target=category.id)", categoriesUsed);
+                "SELECT DISTINCT(category.t_fullname) FROM category, suboperation WHERE suboperation.r_category_id=category.id UNION ALL "
+                "SELECT DISTINCT(category.t_fullname) FROM category, budget WHERE budget.rc_category_id=category.id UNION ALL "
+                "SELECT DISTINCT(category.t_fullname) FROM category, budgetrule WHERE budgetrule.rc_category_id=category.id UNION ALL "
+                "SELECT DISTINCT(category.t_fullname) FROM category, budgetrule WHERE budgetrule.rc_category_id_target=category.id)", categoriesUsed);
 
         for (int i = 0; i < categoriesUsed.count(); ++i) { //Warning categoriesUsed is modified in the loop
             QString cat = categoriesUsed.at(i);
