@@ -126,16 +126,17 @@ public:
 
 Q_SIGNALS:
     /**
-     * Request to import a list of files
-     * @param iFiles the list of files
+     * Request to import a file
+     * @param iFile the file
      */
-    void importFile(const QStringList& iFiles);
+    void importFileName(const QString& iFile);
 
 private Q_SLOTS:
-    void import(const QStringList& iFiles = QStringList());
+    void import(const QString& iFile);
+    void import(const QList<KUrl>& iFiles = QList<KUrl>());
     void importbackends();
     void exportFile();
-    void foundTransfer();
+    void findTransfers();
     void anonymize();
     void cleanBanks();
     void validateImportedOperations();
