@@ -56,6 +56,16 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
+    QStringList overlayopen;
+    overlayopen.push_back("skg_open");
+    m_menuOpen = new KAction(KIcon("view-investment", NULL, overlayopen), i18nc("Verb", "Open report..."), this);
+    connect(m_menuOpen, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+    addAction(m_menuOpen);
+
+    QAction* sep = new QAction(this);
+    sep->setSeparator(true);
+    addAction(sep);
+
     m_menuTransfert = new KAction(i18nc("Noun, a type of operations", "Transfers"), this);
     m_menuTransfert->setCheckable(true);
     m_menuTransfert->setChecked(false);
@@ -68,6 +78,12 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     connect(m_menuTracked, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuTracked);
 
+    m_menuSuboperation = new KAction(i18nc("Noun, a type of operations", "On suboperations"), this);
+    m_menuSuboperation->setCheckable(true);
+    m_menuSuboperation->setChecked(false);
+    connect(m_menuSuboperation, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    addAction(m_menuSuboperation);
+
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
@@ -87,6 +103,7 @@ QString SKGOperationBoardWidget::getState()
 
     root.setAttribute("menuTransfert", m_menuTransfert && m_menuTransfert->isChecked() ? "Y" : "N");
     root.setAttribute("menuTracked", m_menuTracked && m_menuTracked->isChecked() ? "Y" : "N");
+    root.setAttribute("menuSuboperation", m_menuSuboperation && m_menuSuboperation->isChecked() ? "Y" : "N");
     return doc.toString();
 }
 
@@ -97,6 +114,7 @@ void SKGOperationBoardWidget::setState(const QString& iState)
     QDomElement root = doc.documentElement();
     if (m_menuTransfert) m_menuTransfert->setChecked(root.attribute("menuTransfert") == "Y");
     if (m_menuTracked) m_menuTracked->setChecked(root.attribute("menuTracked") != "N");
+    if (m_menuSuboperation) m_menuSuboperation->setChecked(root.attribute("menuSuboperation") == "Y");
 
     dataModified("", 0);
 }
@@ -121,7 +139,8 @@ void SKGOperationBoardWidget::onOpen(const QString& iLink)
     else if (iLink == "EP") title = i18nc("Title of a list of operations", "Expenses of previous month");
     else if (iLink == "SP") title = i18nc("Title of a list of operations", "Savings of previous month");
 
-    SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/?title_icon=view-financial-list&currentPage=-1&title=" % SKGServices::encodeForUrl(title) %
+    bool onSubOperation = (m_menuSuboperation && m_menuSuboperation->isChecked());
+    SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/" % QString(onSubOperation ? "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/" : "") % "?operationTable=" % SKGServices::encodeForUrl(onSubOperation ? "v_operation_consolidated" : "v_operation_display") % "&title_icon=view-financial-list&currentPage=-1&title=" % SKGServices::encodeForUrl(title) %
                                            "&operationWhereClause=" % SKGServices::encodeForUrl(wc)
                                           );
 }
@@ -130,7 +149,10 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
 {
     SKGTRACEIN(10, "SKGOperationBoardWidget::dataModified");
     Q_UNUSED(iIdTransaction);
-    if (iTableName == "v_operation_display" || iTableName.isEmpty()) {
+    QString table = (m_menuSuboperation && m_menuSuboperation->isChecked() ? "v_operation_consolidated" : "v_operation_display");
+    QString amount = (m_menuSuboperation && m_menuSuboperation->isChecked() ? "f_REALCURRENTAMOUNT" : "f_CURRENTAMOUNT");
+
+    if (iTableName == table || iTableName.isEmpty()) {
         //Get month
         QDate date = QDate::currentDate();
         date = date.addDays(1 - date.day());
@@ -140,13 +162,23 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
 
         SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
         if (doc) {
+            if (m_menuOpen) {
+                QString url = QString("skg://skrooge_report_plugin/?grouped=")
+                              % (m_menuTransfert && m_menuTransfert->isChecked() ? "Y" : "N") % "&transfers="
+                              % (m_menuTransfert && m_menuTransfert->isChecked() ? "Y" : "N") % "&tracked="
+                              % (m_menuTracked && m_menuTracked->isChecked() ? "Y" : "N") % "&expenses=Y&incomes=Y&lines2=t_TYPEEXPENSENLS&columns=d_DATEMONTH&currentPage=-1" %
+                              "&mode=0&interval=3&period=3" %
+                              "&tableAndGraphState.graphMode=1&tableAndGraphState.allPositive=Y&tableAndGraphState.show=graph&title=" %
+                              SKGServices::encodeForUrl(i18nc("Noun, the title of a section", "Income & Expenditure"));
+                m_menuOpen->setData(url);
+            }
 
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
             SKGServices::SKGUnitInfo secondary = doc->getSecondaryUnit();
 
             SKGStringListList listTmp;
             SKGError err = getDocument()->executeSelectSqliteOrder(
-                               "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TYPEACCOUNT<>'L'"
+                               "SELECT TOTAL(" % amount % "), d_DATEMONTH  from " % table % " WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TYPEACCOUNT<>'L'"
                                % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : "AND t_TRANSFER='N'")
                                % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND t_REFUND=''")
                                % " group by d_DATEMONTH, t_TYPEEXPENSE",
