@@ -1291,14 +1291,16 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
             show->addGroupedItem("templates", i18nc("Option to for display of operations", "Templates"), "skrooge_template", "d_date!='0000-00-00' AND t_template='Y'",
                                  "type");
             show->addSeparator();
-            show->addGroupedItem("hidenone", i18nc("Option to for display of operations", "All"), "dialog-ok", "1=1", "checked");
-            show->addGroupedItem("hide", i18nc("Option to for display of operations", "Hide all checked operations"), "dialog-ok", "t_status<>'Y'", "checked");
-            show->addGroupedItem("hide1w", i18nc("Option to for display of operations", "Hide checked operations > 1 week"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-7 day')", "checked");
-            show->addGroupedItem("hide2w", i18nc("Option to for display of operations", "Hide checked operations > 2 weeks"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-14 day')", "checked");
-            show->addGroupedItem("hide1m", i18nc("Option to for display of operations", "Hide checked operations > 1 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 month')", "checked");
-            show->addGroupedItem("hide3m", i18nc("Option to for display of operations", "Hide checked operations > 3 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-3 month')", "checked");
-            show->addGroupedItem("hide6m", i18nc("Option to for display of operations", "Hide checked operations > 6 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-6 month')", "checked");
-            show->addGroupedItem("hide1y", i18nc("Option to for display of operations", "Hide checked operations > 1 year"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 year')", "checked");
+            show->addItem("hidepointed", i18nc("Option to for display of operations", "Hide pointed operations"), "dialog-ok", "t_status<>'P'");
+            show->addSeparator();
+            show->addGroupedItem("hidenone", i18nc("Option to for display of operations", "Show all checked operations"), "dialog-ok-apply", "1=1", "checked");
+            show->addGroupedItem("hide", i18nc("Option to for display of operations", "Hide all checked operations"), "dialog-ok-apply", "t_status<>'Y'", "checked");
+            show->addGroupedItem("hide1w", i18nc("Option to for display of operations", "Hide checked operations > 1 week"), "dialog-ok-apply", "t_status<>'Y' OR d_date>date('now', '-7 day')", "checked");
+            show->addGroupedItem("hide2w", i18nc("Option to for display of operations", "Hide checked operations > 2 weeks"), "dialog-ok-apply", "t_status<>'Y' OR d_date>date('now', '-14 day')", "checked");
+            show->addGroupedItem("hide1m", i18nc("Option to for display of operations", "Hide checked operations > 1 months"), "dialog-ok-apply", "t_status<>'Y' OR d_date>date('now', '-1 month')", "checked");
+            show->addGroupedItem("hide3m", i18nc("Option to for display of operations", "Hide checked operations > 3 months"), "dialog-ok-apply", "t_status<>'Y' OR d_date>date('now', '-3 month')", "checked");
+            show->addGroupedItem("hide6m", i18nc("Option to for display of operations", "Hide checked operations > 6 months"), "dialog-ok-apply", "t_status<>'Y' OR d_date>date('now', '-6 month')", "checked");
+            show->addGroupedItem("hide1y", i18nc("Option to for display of operations", "Hide checked operations > 1 year"), "dialog-ok-apply", "t_status<>'Y' OR d_date>date('now', '-1 year')", "checked");
             show->setMode(SKGShow::AND);
             if (currentState.isEmpty()) {
                 show->setDefaultState("all;operations;hide");
@@ -1655,20 +1657,22 @@ void SKGOperationPluginWidget::onFocusChanged()
 {
     _SKGTRACEIN(10, "SKGOperationPluginWidget::onFocusChanged");
 
-    if (m_numberFieldIsNotUptodate && ui.kNumberEdit->hasFocus()) {
-        fillNumber();
-    }
+    if (SKGMainPanel::getMainPanel() && SKGMainPanel::getMainPanel()->currentPage() == this) {
+        if (m_numberFieldIsNotUptodate && ui.kNumberEdit->hasFocus()) {
+            fillNumber();
+        }
 
-    bool test = ui.kTypeEdit->hasFocus() ||
-//                  ui.kAmountEdit->hasFocus() ||
-//              ui.kNumberEdit->hasFocus() ||
-                ui.kUnitEdit->hasFocus() ||
-                ui.kCategoryEdit->hasFocus() ||
-                ui.kTrackerEdit->hasFocus() ||
-                ui.kCommentEdit->hasFocus() ||
-                ui.kPayeeEdit->hasFocus()
-                ;
-    if (m_fastEditionAction && SKGMainPanel::getMainPanel()->currentPage() == this) m_fastEditionAction->setEnabled(test);
+        bool test = ui.kTypeEdit->hasFocus() ||
+                    //                  ui.kAmountEdit->hasFocus() ||
+                    //              ui.kNumberEdit->hasFocus() ||
+                    ui.kUnitEdit->hasFocus() ||
+                    ui.kCategoryEdit->hasFocus() ||
+                    ui.kTrackerEdit->hasFocus() ||
+                    ui.kCommentEdit->hasFocus() ||
+                    ui.kPayeeEdit->hasFocus()
+                    ;
+        if (m_fastEditionAction) m_fastEditionAction->setEnabled(test);
+    }
 }
 
 void SKGOperationPluginWidget::onFastEdition()
