@@ -258,7 +258,7 @@ bool SKGPayeePluginWidget::isEditor()
 
 void SKGPayeePluginWidget::onDeleteUnused()
 {
-    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete_unused_payees");
+    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("clean_delete_unused_payees");
     if (act) act->trigger();
 }
 
