@@ -93,6 +93,7 @@ void SKGScheduledPlugin::refresh()
             QString doc_id = m_currentBankDocument->getUniqueIdentifier();
             if (m_docUniqueIdentifier != doc_id && m_currentBankDocument->getParameter("SKG_DB_BANK_VERSION") >= "0.5") {
                 m_docUniqueIdentifier = doc_id;
+                m_cacheAdvice.clear();
 
                 SKGError err;
                 //Read Setting
@@ -125,7 +126,7 @@ SKGBoardWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGHtmlBoardWidget(m_currentBankDocument,
                                 getDashboardWidgetTitle(iIndex),
-                                KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/scheduled_operations.html"),
+                                KStandardDirs().findResource("data", "skrooge/html/default/scheduled_operations.html"),
                                 QStringList() << "v_recurrentoperation_display");
     return NULL;
 }
