@@ -35,13 +35,13 @@ class SKGDocumentBank;
 class SKGScheduledPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGScheduledPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGScheduledPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -74,7 +74,7 @@ public:
      * @param iIndex the index of the widget
      * @return The dashboard widget of the plugin
      */
-    virtual SKGWidget* getDashboardWidget(int iIndex);
+    virtual SKGBoardWidget* getDashboardWidget(int iIndex);
 
     /**
      * Must be modified to refresh widgets after a modification.
@@ -153,7 +153,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -162,13 +162,13 @@ public:
      * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
      *   @see SKGError
      */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution);
 
 private Q_SLOTS:
-    void actionScheduleOperation();
+    void onScheduleOperation();
 
 private:
-    Q_DISABLE_COPY(SKGScheduledPlugin);
+    Q_DISABLE_COPY(SKGScheduledPlugin)
 
     SKGError scheduleOperation(const SKGOperationObject& iOperation, SKGRecurrentOperationObject& oRecurrent) const;
 
@@ -178,6 +178,9 @@ private:
     KAction* m_scheduleOperationAction;
 
     Ui::skgscheduledplugin_pref ui;
+
+    int m_counterAdvice;
+    QList<SKGAdvice> m_cacheAdvice;
 };
 
 #endif // SKGSCHEDULEDPLUGIN_H
