@@ -21,15 +21,14 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include "ui_skgunitpluginwidget_board.h"
-#include "skgwidget.h"
+#include "skgboardwidget.h"
 
 class KAction;
 
 /**
  * This file is Skrooge plugin for unit management
  */
-class SKGUnitBoardWidget : public SKGWidget
+class SKGUnitBoardWidget : public SKGBoardWidget
 {
     Q_OBJECT
 
@@ -63,9 +62,7 @@ private Q_SLOTS:
     void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
 
 private:
-    Q_DISABLE_COPY(SKGUnitBoardWidget);
-
-    Ui::skgunitplugin_board ui;
+    Q_DISABLE_COPY(SKGUnitBoardWidget)
 
     KAction* m_menuFavorite;
     KAction* m_menuCurrencies;
@@ -73,6 +70,8 @@ private:
     KAction* m_menuShares;
     KAction* m_menuObjects;
     KAction* m_menuSharesOwnedOnly;
+
+    QLabel* m_label;
 };
 
 #endif // SKGUNITBOARDWIDGET_H
