@@ -351,7 +351,7 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
                 if (obj->getAttribute("t_TRANSFER") == "Y") return m_iconTransfer;
                 if (obj->getAttribute("i_group_id") != "0") return m_iconGroup;
             } else if (att == "t_CATEGORY") {
-                if (SKGServices::stringToInt(obj->getAttribute("i_NBSUBCATEGORY")) > 1) return m_iconSplit;
+                if (SKGServices::stringToInt(obj->getAttribute("i_NBSUBOPERATIONS")) > 1) return m_iconSplit;
             } else if (att == "i_NBRECURRENT" && m_operationTable) {
                 if (obj->getAttribute("i_NBRECURRENT") != "0") return m_iconRecurrentMaster;
                 else if (obj->getAttribute("r_recurrentoperation_id") != "0") return m_iconRecurrent;
@@ -577,7 +577,7 @@ else return KIcon();
                     SKGRecurrentOperationObject rop(*obj);
                     rop.getParentOperation(op);
                 }
-                if (SKGServices::stringToInt(op.getAttribute("i_NBSUBCATEGORY")) > 1) {
+                if (SKGServices::stringToInt(op.getAttribute("i_NBSUBOPERATIONS")) > 1) {
                     SKGObjectBase::SKGListSKGObjectBase subOps;
                     op.getSubOperations(subOps);
                     foreach(const SKGObjectBase & subOp, subOps) {
