@@ -100,7 +100,7 @@ SKGError SKGAccountObject::getInitialBalance(double& oBalance, SKGUnitObject& oU
 
     //Get initial balance
     SKGStringListList listTmp;
-    err = getDocument()->executeSelectSqliteOrder("SELECT f_QUANTITY, t_UNIT FROM  v_operation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()), listTmp);
+    err = getDocument()->executeSelectSqliteOrder("SELECT f_QUANTITY, t_UNIT FROM  v_operation_tmp1  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()), listTmp);
     if (!err && listTmp.count() > 1) {
         oBalance = SKGServices::stringToDouble(listTmp.at(1).at(0));
         unitName = listTmp.at(1).at(1);
@@ -194,7 +194,7 @@ SKGError SKGAccountObject::getOperations(SKGListSKGObjectBase& oOperations) cons
 
 double SKGAccountObject::getCurrentAmount() const
 {
-    return SKGServices::stringToDouble(getAttribute("f_CURRENTAMOUNT"));
+    return SKGServices::stringToDouble(getAttributeFromView("v_account_amount", "f_CURRENTAMOUNT"));
 }
 
 double SKGAccountObject::getAmount(const QDate& iDate) const
