@@ -32,23 +32,21 @@
 #include <klocale.h>
 #include <ksavefile.h>
 #include <kservicetypetrader.h>
-#include <kio/netaccess.h>
 
 #include <QRegExp>
 #include <QFileInfo>
 #include <QTextCodec>
 #include <QCryptographicHash>
+#include <QTemporaryFile>
 
 SKGImportExportManager::SKGImportExportManager(SKGDocumentBank* iDocument,
-        const QString& iFileName)
+        const KUrl& iFileName)
     : QObject(), m_document(iDocument), m_fileName(iFileName),
       m_defaultAccount(NULL), m_defaultUnit(NULL),
       m_importPlugin(NULL), m_exportPlugin(NULL)
 {
     setAutomaticValidation(true);
     setAutomaticApplyRules(false);
-
-    KIO::NetAccess::download(KUrl(iFileName), m_localFileName, NULL);
 }
 
 SKGImportExportManager::~SKGImportExportManager()
@@ -61,7 +59,34 @@ SKGImportExportManager::~SKGImportExportManager()
     m_importPlugin = NULL;
     m_exportPlugin = NULL;
 
-    KIO::NetAccess::removeTempFile(m_fileName);
+    if (!m_localFileName.isEmpty() && m_localFileName != getFileName().toLocalFile()) QFile(m_localFileName).remove();
+}
+
+QString SKGImportExportManager::getFileNameExtension() const
+{
+    return QFileInfo(getFileName().path()).suffix().toUpper();
+}
+
+KUrl SKGImportExportManager::getFileName() const
+{
+    return m_fileName;
+}
+
+QString SKGImportExportManager::getLocalFileName(bool iDownload)
+{
+    if (m_localFileName.isEmpty()) {
+        if (getFileName().isLocalFile()) m_localFileName = getFileName().toLocalFile();
+        else {
+            if (iDownload) SKGServices::download(KUrl(getFileName()), m_localFileName);
+            else {
+                QTemporaryFile tmpFile;
+                tmpFile.setAutoRemove(false);
+                tmpFile.open();
+                m_localFileName = tmpFile.fileName();
+            }
+        }
+    }
+    return m_localFileName;
 }
 
 SKGError SKGImportExportManager::setDefaultAccount(SKGAccountObject* iAccount)
@@ -79,7 +104,7 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
     SKGError err;
     SKGTRACEINRC(10, "SKGImportExportManager::getDefaultAccount", err);
     if (m_defaultAccount == NULL && m_document) {
-        QFileInfo fInfo(m_fileName);
+        QFileInfo fInfo(getLocalFileName());
         QStringList items = fInfo.baseName().split('@');
         QString bankname;
         QString number;
@@ -88,8 +113,11 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         else bankname = name;
         name.replace('_', ' ');
         name.replace('-', ' ');
-        QRegExp rx("(\\d+)");
-        if (rx.indexIn(name) != -1) number = rx.cap(1);
+        QRegExp rx("(\\d{6,})");
+        if (rx.indexIn(name) != -1) {
+            number = rx.cap(1);
+            if (name != number) name = name.remove(number).trimmed();
+        }
 
         //Searching if an account exist
         QString whereClause = "t_name='" % name % '\'';
@@ -248,7 +276,7 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
         if (m_since_last_import && !err) {
             SKGTRACEINRC(2, "SKGImportExportManager::finalizedImportedOperations-deletebeforelastimport", err);
             err = m_document->executeSqliteOrder("DELETE FROM operation WHERE operation.t_imported='T' AND "
-                                                 "EXISTS(SELECT 1 FROM operation o WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND o.d_date>=operation.d_date)");
+                                                 "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND o.d_date>=operation.d_date)");
         }
 
         //For performances
@@ -446,8 +474,8 @@ SKGError SKGImportExportManager::importFile()
             if (pluginInterface) {
                 //Import
                 fileTreated = true;
-                SKGTRACEL(2) << "Input filename=" << m_fileName << endl;
-                SKGTRACEL(2) << "Input local filename=" << m_localFileName << endl;
+                SKGTRACEL(2) << "Input filename=" << m_fileName.prettyUrl() << endl;
+                SKGTRACEL(2) << "Input local filename=" << getLocalFileName() << endl;
                 err = pluginInterface->importFile();
             }
 
@@ -478,11 +506,10 @@ SKGError SKGImportExportManager::exportFile()
             if (pluginInterface) {
                 //Import
                 fileTreated = true;
-                SKGTRACEL(2) << "Input filename=" << m_fileName << endl;
-                SKGTRACEL(2) << "Input local filename=" << m_localFileName << endl;
+                SKGTRACEL(2) << "Input filename=" << m_fileName.prettyUrl() << endl;
+                SKGTRACEL(2) << "Input local filename=" << getLocalFileName(false) << endl;
                 err = pluginInterface->exportFile();
-                if (!err && !KIO::NetAccess::upload(m_localFileName, KUrl(m_fileName), NULL))
-                    err = SKGError(ERR_WRITEACCESS, KIO::NetAccess::lastErrorString());
+                if (!err) err = SKGServices::upload(KUrl::fromLocalFile(getLocalFileName(false)), m_fileName);
             }
 
             if (!err && !fileTreated) {
@@ -643,7 +670,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged)
             SKGStringListList listTmp;
             //+A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
             err = m_document->executeSelectSqliteOrder(
-                      "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE A.id<=B.id AND A.rc_unit_id=B.rc_unit_id AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND A.f_QUANTITY=-B.f_QUANTITY AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_QUANTITY!=0",
+                      "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND A.f_QUANTITY=-B.f_QUANTITY AND A.i_group_id=0 AND B.i_group_id=0 AND A.f_QUANTITY!=0",
                       listTmp);
             //Step 1 done
             if (!err) err = m_document->stepForward(1);
@@ -651,7 +678,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged)
             SKGStringListList listTmp2;
             //+A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
             if (!err) err = m_document->executeSelectSqliteOrder(
-                                    "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND A.f_CURRENTAMOUNT=-P.t_value AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0",
+                                    "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND A.f_CURRENTAMOUNT=-P.t_value AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0",
                                     listTmp2);
 
             //Step 2 done
