@@ -268,39 +268,33 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
         //Yes
         err = setAttribute("i_group_id", "0");
     } else {
-        //No
-        //Is a group already existing ?
-        QString existingGroup = getAttribute("i_group_id");
-        if (existingGroup == "0" || existingGroup.isEmpty()) existingGroup = iOperation.getAttribute("i_group_id");
-
-        if (existingGroup == "0" || existingGroup.isEmpty()) {
-            //No, we have to create a new group
-            SKGStringListList result;
-            err = getDocument()->executeSelectSqliteOrder("SELECT max(i_group_id) from operation", result);
-            if (!err) {
-                //Compute new group id
-                QString newIdGroup('1');
-                if (result.count() == 2) {
-                    newIdGroup = SKGServices::intToString(SKGServices::stringToInt(result.at(1).at(0)) + 1);
-                }
-
-                //Set group id
-                SKGOperationObject op1 = SKGOperationObject(iOperation.getDocument(), iOperation.getID());
-                err = op1.setAttribute("i_group_id", newIdGroup);
-                if (!err) err = op1.save();
-
-                if (!err) err = setAttribute("i_group_id", newIdGroup);
+        //Get previous groups
+        QString group1 = getAttribute("i_group_id");
+        QString group2 = iOperation.getAttribute("i_group_id");
 
+        //Create a new group
+        SKGStringListList result;
+        err = getDocument()->executeSelectSqliteOrder("SELECT max(i_group_id) from operation", result);
+        if (!err) {
+            //Compute new group id
+            QString newIdGroup('1');
+            if (result.count() == 2) {
+                newIdGroup = SKGServices::intToString(SKGServices::stringToInt(result.at(1).at(0)) + 1);
             }
-        } else {
-            //Yes, all operation must be grouped
-            SKGOperationObject op1 = iOperation;
-            err = op1.setAttribute("i_group_id", existingGroup);
-            if (!err) err = op1.save();
 
-            if (!err) err = setAttribute("i_group_id", existingGroup);
+            //Set group id
+            SKGOperationObject op1 = SKGOperationObject(iOperation.getDocument(), iOperation.getID());
+            err = op1.setAttribute("i_group_id", newIdGroup);
+            if (!err) err = op1.save(true, false);
+
+            if (!err) err = setAttribute("i_group_id", newIdGroup);
+
+            //Update all objects of group2
+            if (!err && !group1.isEmpty() && group1 != "0") err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group1);
+
+            //Update all objects of group2
+            if (!err && !group1.isEmpty() && group2 != "0") err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group2);
         }
-
     }
 
     return err;
@@ -353,7 +347,7 @@ bool SKGOperationObject::isTemplate() const
 
 int SKGOperationObject::getNbSubOperations() const
 {
-    return SKGServices::stringToInt(getAttribute("i_NBSUBCATEGORY"));
+    return SKGServices::stringToInt(getAttribute("i_NBSUBOPERATIONS"));
 }
 
 SKGError SKGOperationObject::addSubOperation(SKGSubOperationObject& oSubOperation)
@@ -457,7 +451,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     if (!err) err = save();
 
     //Merge suboperations
-    if (getCurrentAmount() != iDeletedOne.getCurrentAmount()) {
+    if (qAbs(getCurrentAmount() - iDeletedOne.getCurrentAmount()) > 0.0001) {
         SKGObjectBase::SKGListSKGObjectBase subOps1;
         if (!err) err = getSubOperations(subOps1);
 
