@@ -101,11 +101,6 @@ QString SKGPayeeObject::getAddress() const
     return getAttribute("t_address");
 }
 
-double SKGPayeeObject::getCurrentAmount() const
-{
-    return SKGServices::stringToDouble(getAttribute("f_CURRENTAMOUNT"));
-}
-
 SKGError SKGPayeeObject::bookmark(bool iBookmark)
 {
     return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
