@@ -482,12 +482,10 @@ QVariantList SKGReportBank::getIncomeVsExpenditure()
         if (doc) {
             QString month = getMonth();
             QString previousmonth = getPreviousMonth();
-            SKGStringListList listTmp;
-            SKGError err = doc->executeSelectSqliteOrder(
-                               "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TRANSFER='N' group by d_DATEMONTH, t_TYPEEXPENSE",
-                               listTmp);
-            int nbval = listTmp.count();
-            if (!err && nbval > 1) {
+            SKGObjectBase::SKGListSKGObjectBase ops;
+            SKGError err = doc->getObjects("v_operation_display", "d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TRANSFER='N'", ops);
+            int nbval = ops.count();
+            if (!err && nbval > 0) {
                 QVariantList line;
                 line << "sum" << "" << previousmonth << month << "max";
                 table.push_back(line);
@@ -497,13 +495,15 @@ QVariantList SKGReportBank::getIncomeVsExpenditure()
                 double income_month = 0;
                 double expense_month = 0;
 
-                for (int i = 1; i < nbval; ++i) { //Ignore header
-                    QString m = listTmp.at(i).at(1);
-                    double v = SKGServices::stringToDouble(listTmp.at(i).at(0));
-                    if (v > 0 && m == month) income_month = v;
-                    else if (v < 0 && m == month) expense_month = v;
-                    else if (v > 0 && m == previousmonth) income_previous_month = v;
-                    else if (v < 0 && m == previousmonth) expense_previous_month = v;
+                for (int i = 0; i < nbval; ++i) {
+                    SKGOperationObject op(ops.at(i));
+                    QString m = op.getAttribute("d_DATEMONTH");
+                    QDate d = QDate::fromString(m, "yyyy-MM").addMonths(1).addDays(-1);
+                    double v = op.getAmount(d);
+                    if (v > 0 && m == month) income_month += v;
+                    else if (v < 0 && m == month) expense_month += v;
+                    else if (v > 0 && m == previousmonth) income_previous_month += v;
+                    else if (v < 0 && m == previousmonth) expense_previous_month += v;
                 }
                 double saving_previous_month = income_previous_month + expense_previous_month;
                 double saving_month = income_month + expense_month;
@@ -573,6 +573,7 @@ void SKGReportBank::addItemsInMapping(QVariantHash& iMapping)
     iMapping.insert("msg_no_highlighted", i18nc("A monthly report message", "No highlighted operations defined on the \"<a href=\"%1\">Operations</a>\" page.", "skg://Skrooge_operation_plugin/"));
     iMapping.insert("msg_no_budget", i18nc("A monthly report message", "No budget defined on the \"<a href=\"%1\">Budget</a>\" page.", "skg://Skrooge_budget_plugin/"));
     iMapping.insert("msg_no_share", i18nc("A monthly report message", "No share defined on the \"<a href=\"%1\">Unit</a>\" page.", "skg://Skrooge_unit_plugin/"));
+    iMapping.insert("msg_amount_unit_date", i18nc("A monthly report message", "All amounts are calculated using the unit rates of the last day of the corresponding month."));
 }
 
 #include "skgreportbank.moc"
