@@ -53,8 +53,7 @@ const SKGRuleObject& SKGRuleObject::operator= (const SKGObjectBase& iObject)
 }
 
 SKGRuleObject::~SKGRuleObject()
-{
-}
+{}
 
 QString SKGRuleObject::getDisplayName() const
 {
@@ -64,7 +63,6 @@ QString SKGRuleObject::getDisplayName() const
 SKGError SKGRuleObject::bookmark(bool iBookmark)
 {
     return setAttribute("t_bookmarked", iBookmark ? "Y" : "N");
-
 }
 
 bool SKGRuleObject::isBookmarked() const
@@ -318,10 +316,20 @@ QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QSt
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to lower");
     else if (output == "#ATT#=upper(#ATT#)")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to upper");
+    else if (output == "#ATT#=capitalize(#ATT#)")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to capitalize");
     else if (output == "#ATT#!=lower(#ATT#)")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not lower");
     else if (output == "#ATT#!=upper(#ATT#)")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not upper");
+    else if (output == "#ATT#!=capitalize(#ATT#)")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is not capitalize");
+    else if (output == "#ATT#= lower(#ATT#)")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is lower");
+    else if (output == "#ATT#= upper(#ATT#)")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is upper");
+    else if (output == "#ATT#= capitalize(#ATT#)")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is capitalize");
 
     else if (output == "#ATT#=replace(#ATT2#,'#V1S#','#V2S#')")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2# with '#V1S#' replaced by '#V2S#'").replace("#V1S#", iParam1).replace("#V2S#", iParam2).replace("#ATT2#", iAtt2);
@@ -369,6 +377,7 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT#='#V1S#'");
             output.push_back("#ATT#=lower(#ATT#)");
             output.push_back("#ATT#=upper(#ATT#)");
+            output.push_back("#ATT#=capitalize(#ATT#)");
             output.push_back("#ATT#=replace(#ATT2#,'#V1S#','#V2S#')");
         } else if (iAttributeType == SKGServices::INTEGER || iAttributeType == SKGServices::FLOAT) {
             output.push_back("#ATT#=#V1#");
@@ -389,8 +398,12 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT# LIKE '%#V1S#'");
             output.push_back("#ATT#=''");
             output.push_back("#ATT#!=''");
+            output.push_back("#ATT#= lower(#ATT#)");
             output.push_back("#ATT#!=lower(#ATT#)");
+            output.push_back("#ATT#= upper(#ATT#)");
             output.push_back("#ATT#!=upper(#ATT#)");
+            output.push_back("#ATT#= capitalize(#ATT#)");
+            output.push_back("#ATT#!=capitalize(#ATT#)");
             output.push_back("REGEXP('#V1S#', #ATT#)");
             output.push_back("WILDCARD('#V1S#', #ATT#)");
         }
@@ -445,9 +458,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
     QStringList output;
     if (iFullUpdate) {
         //Add markers
-        output.push_back("UPDATE suboperation set i_tmp=1 WHERE id IN (SELECT i_SUBOPID FROM v_operation_prop WHERE #WC#)");
-        output.push_back("UPDATE operation set i_tmp=1 WHERE id IN (SELECT id FROM v_operation_prop WHERE #WC#)");
-        output.push_back("UPDATE parameters set i_tmp=1 WHERE id IN (SELECT i_PROPPID FROM v_operation_prop WHERE #WC#)");
+        output.push_back("UPDATE v_operation_prop set i_tmp=1 WHERE #WC#");
     }
 
     QDomDocument doc("SKGML");
@@ -516,9 +527,11 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                         attribute2 = SKGServices::stringToSqlString(attribute2);
                         if (attribute2.startsWith(QLatin1String("p_"))) {
                             QString propertyName = attribute2.right(attribute2.length() - 2);
-                            attribute2 = "IFNULL((SELECT v_operation_prop.i_PROPVALUE FROM v_operation_prop WHERE v_operation_prop.id=operation.id AND v_operation_prop.i_PROPPNAME='" % SKGServices::stringToSqlString(propertyName) % "'),'')";
-                        } else {
-                            attribute2 = "(SELECT " % attribute2 % " FROM v_operation_consolidated WHERE v_operation_consolidated.id=operation.id)";
+                            attribute2 = "IFNULL((SELECT op2.i_PROPVALUE FROM v_operation_prop op2 WHERE op2.id=v_operation_prop.id AND op2.i_PROPPNAME='" % SKGServices::stringToSqlString(propertyName) % "'),'')";
+                        }
+
+                        if (element.attribute("attribute").startsWith(QLatin1String("p_"))) {
+                            attribute2 = "(SELECT " % attribute2 %  " FROM v_operation_prop WHERE i_PROPPID=parameters.id)";
                         }
                     }
                     elementDescription = elementDescription.replace("#ATT2#", attribute2);
@@ -557,27 +570,12 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                                         }
                                     }
                                     output.push_back("UPDATE suboperation set r_category_id=(SELECT id FROM category WHERE " % elementDescription % ") WHERE i_tmp=1");
-                                } else if (attribute == "t_REALCOMMENT") {
-                                    elementDescription.replace(attribute, "t_comment");
-                                    output.push_back("UPDATE suboperation set " % elementDescription % " WHERE i_tmp=1 AND NOT(" % elementDescription % ')');
-                                } else if (attribute == "t_ACCOUNT") {
-                                    elementDescription.replace(attribute, "t_name");
-                                    output.push_back("INSERT OR IGNORE INTO account (t_name, rd_bank_id) VALUES ('" % SKGServices::stringToSqlString(element.attribute("value")) % "', (SELECT MIN(id) FROM bank))");
-                                    output.push_back("UPDATE operation set rd_account_id=(SELECT id FROM account WHERE " % elementDescription % ") WHERE i_tmp=1");
-                                } else if (attribute == "t_PAYEE") {
-                                    elementDescription.replace(attribute, "t_name");
-                                    output.push_back("INSERT OR IGNORE INTO payee (t_name) VALUES ('" % SKGServices::stringToSqlString(element.attribute("value")) % "')");
-                                    output.push_back("UPDATE operation set r_payee_id=(SELECT id FROM payee WHERE " % elementDescription % ") WHERE i_tmp=1");
-                                } else if (attribute == "t_REALREFUND") {
-                                    elementDescription.replace(attribute, "t_name");
-                                    output.push_back("INSERT OR IGNORE INTO refund (t_name) VALUES ('" % SKGServices::stringToSqlString(element.attribute("value")) % "')");
-                                    output.push_back("UPDATE suboperation set r_refund_id=(SELECT id FROM refund WHERE " % elementDescription % ") WHERE i_tmp=1");
                                 } else if (element.attribute("attribute").startsWith(QLatin1String("p_"))) {
                                     output.push_back("INSERT OR IGNORE INTO parameters (t_uuid_parent, t_name, i_tmp) SELECT o.id||'-operation', '" % SKGServices::stringToSqlString(propName) % "', 1 FROM operation o WHERE o.i_tmp=1");
                                     output.push_back("UPDATE parameters set " % elementDescription % " WHERE i_tmp=1 AND t_name='" % SKGServices::stringToSqlString(propName) % "' AND NOT(" % elementDescription % ')');
                                     output.push_back("DELETE FROM parameters WHERE i_tmp=1 AND t_name='" % SKGServices::stringToSqlString(propName) % "' AND t_value=''");
                                 } else {
-                                    output.push_back("UPDATE operation set " % elementDescription % " WHERE i_tmp=1 AND NOT(" % elementDescription % ')');
+                                    output.push_back("UPDATE v_operation_prop set " % elementDescription % " WHERE i_tmp=1 AND NOT(" % elementDescription % ')');
                                 }
                             }
                         } else if (iType == ALARM) {
@@ -604,9 +602,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
 
     if (iFullUpdate) {
         //Remove markers
-        output.push_back("UPDATE parameters set i_tmp=0 WHERE i_tmp=1");
-        output.push_back("UPDATE suboperation set i_tmp=0 WHERE i_tmp=1");
-        output.push_back("UPDATE operation set i_tmp=0 WHERE i_tmp=1");
+        output.push_back("UPDATE v_operation_prop set i_tmp=0 WHERE i_tmp=1");
     }
     return output;
 }
