@@ -113,7 +113,7 @@ QString SKGTrackerObject::getComment() const
 
 double SKGTrackerObject::getCurrentAmount() const
 {
-    return SKGServices::stringToDouble(getAttribute("f_CURRENTAMOUNT"));
+    return SKGServices::stringToDouble(getAttributeFromView("v_refund_amount", "f_CURRENTAMOUNT"));
 }
 
 SKGError SKGTrackerObject::merge(const SKGTrackerObject& iTracker)
