@@ -116,7 +116,8 @@ QStringList SKGUnitObject::getListofKnownCurrencies(bool iIncludingObsolete)
             << i18nc("Noun, a currency", "DAX")
             << i18nc("Noun, a currency", "NIKKEI 225")
             << i18nc("Noun, a currency", "HANG SENG")
-            << i18nc("Noun, a currency", "STRAITS TIMES");
+            << i18nc("Noun, a currency", "STRAITS TIMES")
+            << i18nc("Noun, a currency", "Bitcoin");
 
     return output;
 }
@@ -154,6 +155,7 @@ SKGServices::SKGUnitInfo SKGUnitObject::getUnitInfo(const QString& iUnitName)
     SKGServices::SKGUnitInfo info;
     info.NbDecimal = 2;
     info.Value = -1;
+    info.Source = "Yahoo";
 
     QString isoCode = getInternationalCode(iUnitName);
 
@@ -241,12 +243,21 @@ SKGServices::SKGUnitInfo SKGUnitObject::getUnitInfo(const QString& iUnitName)
         info.Date = QDate(1920, 1, 1);
         info.Country = i18nc("Noun, a country", "Singapore");
         info.Internet = "^STI";
+    } else if (iUnitName == i18nc("Noun, a currency", "Bitcoin")) {
+        //BITCOIN
+        info.Name = iUnitName;
+        info.Symbol = "BTC";
+        info.Date = QDate(2009, 2, 4);
+        info.Country = i18nc("Noun, the country of bitcoin", "Internet");
+        info.Internet = "mtgoxUSD";
+        info.Source = "BitcoinCharts";
+        info.Parent = "USD";
+        info.NbDecimal = 4;
     }
 
     return info;
 }
 
-
 SKGError SKGUnitObject::createCurrencyUnit(SKGDocumentBank* iDocument, const QString& iUnitName, SKGUnitObject& oUnit)
 {
     SKGError err;
@@ -300,6 +311,7 @@ SKGError SKGUnitObject::createCurrencyUnit(SKGDocumentBank* iDocument, const QSt
         if (!err) err = oUnit.setType(type);
         if (!err) err = oUnit.setSymbol(info.Symbol);
         if (!err) err = oUnit.setInternetCode(info.Internet);
+        if (!err) err = oUnit.setDownloadSource(info.Source);
         if (!err) err = oUnit.setCountry(info.Country);
         if (!err) err = oUnit.setNumberDecimal(info.NbDecimal);
         if (!err && parentUnit.exist()) err = oUnit.setUnit(parentUnit);
@@ -660,19 +672,19 @@ SKGError SKGUnitObject::addSource(const QString& iNewSource)
             out << "url=http://server/?s=%1" << endl << endl;
 
             out << "#" << i18nc("Description test for a text file used to define a source of download",
-                                "The mode (HTML or CSV). In HTML mode, only one value will be extracted from downloaded page. In CSV mode, a value per line will be extracted.") << endl;
-            out << "mode=CSV or HTML" << endl << endl;
+                                "The mode (HTML or CSV or CSVR). In HTML mode, only one value will be extracted from downloaded page. In CSV mode, a value per line will be extracted. CSVR means CSV in reverse mode.") << endl;
+            out << "mode=CSV, CSVR or or HTML" << endl << endl;
 
             out << "#" << i18nc("Description test for a text file used to define a source of download",
-                                "The regular expression for the price (see %1)", "http://doc.qt.nokia.com/latest/qregexp.html") << endl;
+                                "The regular expression for the price (see %1)", "http://qt-project.org/doc/qt-4.8/qregexp.html") << endl;
             out << "price=" << endl << endl;
 
             out << "#" << i18nc("Description test for a text file used to define a source of download",
-                                "The regular expression for the date (see %1)", "http://doc.qt.nokia.com/latest/qregexp.html") << endl;
+                                "The regular expression for the date (see %1)", "http://qt-project.org/doc/qt-4.8/qregexp.html") << endl;
             out << "date=" << endl << endl;
 
             out << "#" << i18nc("Description test for a text file used to define a source of download",
-                                "The format of the date (see %1)", "http://qt-project.org/doc/qt-5.0/qdate.html#fromString") << endl;
+                                "The format of the date (see %1) or \"UNIX\" for unix time", "http://qt-project.org/doc/qt-4.8/qdate.html#fromString-2") << endl;
             out << "dateformat=yyyy-MM-dd" << endl;
 
             //Close file
@@ -785,8 +797,8 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
             //Download history
             if (!last) {
                 QString path = "http://ichart.finance.yahoo.com/table.csv?s=" % code % "&ignore=.csv&" % parameters;
-                QString stream;
-                SKGError err = SKGServices::download(KUrl(path), stream);
+                QByteArray stream;
+                SKGError err = SKGServices::downloadToStream(KUrl(path), stream);
                 if (!err) {
                     //The file is something like this
                     //Date,Open,High,Low,Close,Volume,Adj Close
@@ -1001,8 +1013,8 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                 }
 
                 QString path = "http://download.finance.yahoo.com/d/quotes.csv?s=" % code % "&f=l1d1" % yahooString;//l1=val d1=date
-                QString stream;
-                SKGError errTmp = SKGServices::download(KUrl(path), stream);
+                QByteArray stream;
+                SKGError errTmp = SKGServices::downloadToStream(KUrl(path), stream);
                 if (!errTmp) {
                     //Read line
                     QString line = stream.trimmed();
@@ -1055,18 +1067,18 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     QString dateFormat = properties["dateformat"];
 
                     //Download url
-                    QString stream;
-                    SKGServices::download(KUrl(path), stream);
+                    QByteArray stream;
+                    SKGServices::downloadToStream(KUrl(path), stream);
                     if (!stream.isEmpty()) {
                         //Parse data
                         QRegExp priceRegExp(price, Qt::CaseInsensitive);
                         QRegExp dateRegExp(date, Qt::CaseInsensitive);
 
-                        QStringList lines = (mode == "CSV" ? SKGServices::splitCSVLine(stream, '\n') : QStringList() << "" << stream);
+                        QStringList lines = (mode.startsWith(QLatin1String("CSV")) ? SKGServices::splitCSVLine(stream, '\n') : QStringList() << "" << stream);
                         int nb = lines.count();
                         int nbLoaded = 0;
                         for (int i = 1; i < nb && !err && (i < nbMaxValues - 1 || nbMaxValues == 0); ++i) { //-1 because the value of the day will be loaded after
-                            QString data = lines.at(i).trimmed();
+                            QString data = lines.at(mode == "CSVR" ? nb - i : i).trimmed();
                             if (!data.isEmpty()) {
                                 SKGTRACEL(1) << "Downloaded data from [" << path << "]=[" << data << "]" << endl;
 
@@ -1079,7 +1091,10 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
 
                                 //Set value
                                 if (val) {
-                                    QDate ds = QDate::fromString(d, dateFormat);
+                                    QDate ds;
+                                    if (dateFormat == "UNIX")
+                                        ds = QDateTime::fromTime_t(SKGServices::stringToInt(d)).date();
+                                    else ds = QDate::fromString(d, dateFormat);
                                     if (!ds.isValid()) ds = QDate::currentDate();
                                     if (!dateFormat.contains("yyyy") && ds.year() < 2000) ds = ds.addYears(100);
 
@@ -1093,7 +1108,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                                     nbLoaded++;
                                 }
                             }
-                            if (nbLoaded == 0) err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2'", getName(), SKGServices::stringToHtml(price))); //TODO does not work with html
+                            if (nbLoaded == 0) err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2' in line '%3'", getName(), SKGServices::stringToHtml(price), data)); //TODO does not work with html
                         }
                     } else {
                         doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, KIO::NetAccess::lastErrorString()));
