@@ -22,7 +22,7 @@
 #include "skggraphicsviewdesignerplugin.h"
 #include "skggraphicsview.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
