@@ -96,6 +96,7 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     SKGTRACEIN(1, "SKGMainPanel::SKGMainPanel");
 
     setComponentData(KGlobal::mainComponent());
+    setObjectName(KGlobal::mainComponent().aboutData()->appName());
 
     //Set main panel
     m_mainPanel = this;
@@ -158,52 +159,54 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
             KPluginFactory* factory = loader.factory();
             if (factory) {
                 SKGInterfacePlugin* pluginInterface = factory->create<SKGInterfacePlugin> (this);
-                if (pluginInterface && pluginInterface->isEnabled() && pluginInterface->setupActions(getDocument(), iArguments)) {
-                    //Add plugin in about
-                    if (about) {
-                        QString author = service->property("X-KDE-PluginInfo-Author", QVariant::String).toString();
-                        if (!author.isEmpty()) {
-                            QString authorId;
-                            QStringList authors = SKGServices::splitCSVLine(author, ',');
-                            if (authors.count() == 2) {
-                                author = authors.at(0);
-                                authorId = authors.at(1);
-                            }
-                            int pos = listAuthors.indexOf(author);
-                            if (pos == -1) {
-                                listAuthors.push_back(author);
-                                listTasks.push_back(i18n("Developer of plugin '%1'", name));
-                                listEmails.push_back(email);
-                                listOscs.push_back(authorId);
-                            } else {
-                                listTasks[pos] += i18n(", '%1'", name);
+                if (pluginInterface) {
+                    if (pluginInterface->isEnabled() && pluginInterface->setupActions(getDocument(), iArguments)) {
+                        //Add plugin in about
+                        if (about) {
+                            QString author = service->property("X-KDE-PluginInfo-Author", QVariant::String).toString();
+                            if (!author.isEmpty()) {
+                                QString authorId;
+                                QStringList authors = SKGServices::splitCSVLine(author, ',');
+                                if (authors.count() == 2) {
+                                    author = authors.at(0);
+                                    authorId = authors.at(1);
+                                }
+                                int pos = listAuthors.indexOf(author);
+                                if (pos == -1) {
+                                    listAuthors.push_back(author);
+                                    listTasks.push_back(i18n("Developer of plugin '%1'", name));
+                                    listEmails.push_back(email);
+                                    listOscs.push_back(authorId);
+                                } else {
+                                    listTasks[pos] += i18n(", '%1'", name);
+                                }
                             }
                         }
-                    }
 
-                    //Store plugin
-                    int nbplugin = m_pluginsList.count();
-                    int pos = nbplugin;
-                    for (int j = nbplugin - 1; j >= 0; --j) {
-                        if (pluginInterface->getOrder() < m_pluginsList.at(j)->getOrder()) {
-                            pos = j;
+                        //Store plugin
+                        int nbplugin = m_pluginsList.count();
+                        int pos = nbplugin;
+                        for (int j = nbplugin - 1; j >= 0; --j) {
+                            if (pluginInterface->getOrder() < m_pluginsList.at(j)->getOrder()) {
+                                pos = j;
+                            }
                         }
-                    }
 
-                    m_pluginsList.insert(pos, pluginInterface);
-                    pluginInterface->setObjectName(id);
+                        m_pluginsList.insert(pos, pluginInterface);
+                        pluginInterface->setObjectName(id);
 
-                    //Build temporary tips file
-                    if (tipsFileOpened) {
-                        QStringList tipsList = pluginInterface->tips();
-                        int nbtips = tipsList.count();
-                        for (int t = 0; t < nbtips; ++t) {
-                            tipsFound = true;
-                            stream << "<tip category=\""
-                                   << id
-                                   << "\"><html>" << SKGServices::stringToHtml(tipsList.at(t))
-                                   << "</html></tip>"
-                                   << endl;
+                        //Build temporary tips file
+                        if (tipsFileOpened) {
+                            QStringList tipsList = pluginInterface->tips();
+                            int nbtips = tipsList.count();
+                            for (int t = 0; t < nbtips; ++t) {
+                                tipsFound = true;
+                                stream << "<tip category=\""
+                                       << id
+                                       << "\"><html>" << SKGServices::stringToHtml(tipsList.at(t))
+                                       << "</html></tip>"
+                                       << endl;
+                            }
                         }
                     }
                 }
@@ -636,6 +639,15 @@ void SKGMainPanel::setupActions()
     connect(m_addTabAction, SIGNAL(triggered()), this, SLOT(addTab()));
     registerGlobalAction("new_tab", m_addTabAction);
 
+    //Add new tab widget
+    QToolButton* addTab = new QToolButton(this);
+    addTab->setIcon(m_addTabAction->icon());
+    addTab->setAutoRaise(true);
+    addTab->raise();
+    addTab->setDefaultAction(m_addTabAction);
+    addTab->setToolButtonStyle(Qt::ToolButtonIconOnly);
+    m_tabWidget->setCornerWidget(addTab);
+
     m_actLock = new KAction(KIcon("document-encrypt"), i18nc("Verb", "Lock panels"), this);
     connect(m_actLock, SIGNAL(triggered(bool)), this, SLOT(onLockDocks()));
     registerGlobalAction("view_lock", m_actLock);
@@ -645,7 +657,6 @@ void SKGMainPanel::setupActions()
     registerGlobalAction("view_unlock", m_actUnLock);
 
     m_switchPinState = new KAction(KIcon("document-encrypt"), i18nc("Noun, user action", "Pin this page"), this);
-    //TODO m_switchPinState->setShortcut(Qt::ALT + Qt::Key_W);
     connect(m_switchPinState, SIGNAL(triggered()), this, SLOT(switchPinPage()));
     registerGlobalAction("tab_switchpin", m_switchPinState);
 
@@ -1473,6 +1484,28 @@ void SKGMainPanel::onBeforeOpenContext()
     m_middleClick = QApplication::mouseButtons() & Qt::MidButton;
 }
 
+void SKGMainPanel::setAttribute(QDomElement& iRoot, const QString& iPath, const QString& iValue)
+{
+    int pos = iPath.indexOf('.');
+    if (pos == -1) {
+        iRoot.setAttribute(iPath, iValue);
+    } else {
+        QString newElementName = iPath.left(pos);
+        QString newAttribue = iPath.right(iPath.count() - pos - 1);
+
+        QDomDocument doc("SKGML");
+        doc.setContent(iRoot.attribute(newElementName));
+        QDomElement root = doc.documentElement();
+        if (root.isNull()) {
+            root = doc.createElement("parameters");
+            doc.appendChild(root);
+        }
+        setAttribute(root, newAttribue, iValue);
+
+        iRoot.setAttribute(newElementName, doc.toString());
+    }
+}
+
 bool SKGMainPanel::openPage(const QUrl& iUrl, bool iNewPage)
 {
     KUrl url(iUrl);
@@ -1497,7 +1530,7 @@ bool SKGMainPanel::openPage(const QUrl& iUrl, bool iNewPage)
                 QStringList listKeys = params.keys();
                 foreach(const QString & k, listKeys) {
                     QString value = KUrl::fromPercentEncoding(params[k].toLatin1());
-                    root.setAttribute(k, value);
+                    setAttribute(root, k, value);
                 }
 
                 //Open page
@@ -1918,6 +1951,8 @@ bool SKGMainPanel::naturalLessThan(const QString& s1, const QString& s2)
 
 bool SKGMainPanel::adviceLessThan(const SKGAdvice& s1, const SKGAdvice& s2)
 {
+    if(s1.getPriority() == s2.getPriority())
+      return (s1.getShortMessage() > s2.getShortMessage());
     return (s1.getPriority() > s2.getPriority());
 }
 
