@@ -271,7 +271,9 @@ void SKGObjectModelBase::refresh()
             QString wc = m_whereClause;
             if (!m_groupby.isEmpty()) {
                 if (wc.isEmpty()) wc = "1=1";
-                wc += " ORDER BY " % m_groupby;
+                if (m_groupby.startsWith(QLatin1String("p_")))
+                    wc += " ORDER BY (SELECT t_value FROM parameters WHERE t_uuid_parent=" % getTable() % ".id||'-" % getRealTable() % "' AND t_name='" % m_groupby % "')";
+                else wc += " ORDER BY " % m_groupby;
             }
             if (m_document) m_document->getObjects(m_table, wc , m_listObjects);
 
@@ -621,31 +623,6 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
             } else if (m_doctransactionTable && att == "t_savestep") {
                 if (obj->getAttribute("t_savestep") == "Y") return qVariantFromValue((QIcon) KIcon("document-save"));
             }
-            /*TODO else if (att.startsWith(QLatin1String("p_")))
-            {
-                //This attribute is a property
-                QVariant blob=obj->getPropertyBlob(att.right(att.count()-2));
-                //Is it a file ?
-                if (!blob.isNull()) {
-                    //Yes, this is a file
-                    QByteArray blob_bytes=blob.toByteArray();
-
-                    //Save temporary file
-                    QString fileName=QDir::tempPath ()+'/'+obj->getAttribute("t_value");
-
-                    QFile file(fileName);
-                    if (file.open(QIODevice::WriteOnly))
-                    {
-                        file.write(blob_bytes);
-                        file.flush();
-                        file.close();
-
-                        ui.kPicture->show();
-                         ui.kOpenBtn->show();
-                         ui.kPicture->showPreview(KUrl(fileName));
-                    }
-                }
-            }*/
         }
         break;
     }
@@ -913,8 +890,13 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
 
 QString SKGObjectModelBase::getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const
 {
-    return iObject.getAttribute(iAttribute);
+    if (iAttribute.startsWith(QLatin1String("p_"))) {
+        //This is a property
+        return iObject.getProperty(iAttribute.right(iAttribute.count() - 2));
+    } else {
+        //This is a real attribute
+        return iObject.getAttribute(iAttribute);
+    }
 }
 
 #include "skgobjectmodelbase.moc"
-
