@@ -22,7 +22,7 @@
 #include "skgshowdesignerplugin.h"
 #include "skgshow.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
