@@ -89,7 +89,7 @@ bool SKGTableWidget::eventFilter(QObject* object, QEvent* event)
                     if (event) event->accept();
                     return true; //stop the process
                 }
-            } else if (kevent->matches(QKeySequence::Copy)) {
+            } else if (kevent->matches(QKeySequence::Copy) && this->state() != QAbstractItemView::EditingState) {
                 copy();
                 if (event) event->accept();
                 return true; //stop the process
