@@ -70,11 +70,11 @@ public:
     /**
      * Graph type
      */
-    Q_ENUMS(GraphType);
+    Q_ENUMS(GraphType)
     /**
      * Additional information to display
      */
-    Q_DECLARE_FLAGS(DisplayAdditionalFlag, DisplayAdditional);
+    Q_DECLARE_FLAGS(DisplayAdditionalFlag, DisplayAdditional)
     /**
      * State of the view
      */
@@ -87,6 +87,10 @@ public:
      * Items selectable or not
      */
     Q_PROPERTY(bool selectable READ isSelectable WRITE setSelectable)
+    /**
+     * Items with shadow or not
+     */
+    Q_PROPERTY(bool shadow READ isShadowVisible WRITE setShadowVisible)
     /**
      * Graph Type
      */
@@ -207,6 +211,18 @@ public Q_SLOTS:
      */
     virtual bool isSelectable() const;
 
+    /**
+     * Enable / disable the shadows
+     * @param iShadow the shadows
+     */
+    virtual void setShadowVisible(bool iShadow);
+
+    /**
+     * Get the shadows visibility
+     * @return the visibility
+     */
+    virtual bool isShadowVisible() const;
+
     /**
      * Set the graph type
      * @param iType the type of graph
@@ -348,7 +364,7 @@ private Q_SLOTS:
     void showMenu(const QPoint& pos);
 
 private:
-    Q_DISABLE_COPY(SKGTableWithGraph);
+    Q_DISABLE_COPY(SKGTableWithGraph)
 
     double computeStepSize(double iRange, double iTargetSteps);
     void addArrow(const QPointF& iPeak, double iSize, double iArrowAngle = 45, double iDegree = 90);
@@ -380,6 +396,7 @@ private:
     bool m_tableVisible;
     bool m_textVisible;
     bool m_zeroVisible;
+    bool m_shadow;
 
     KMenu* m_mainMenu;
     QTimer m_timer;
@@ -408,6 +425,7 @@ private:
     QColor m_tendencyColor;
     QColor m_outlineColor;
     QBrush m_NegativeColor;
+    QBrush m_WhiteColor;
 
     SKGComboBox* m_displayMode;
 };
