@@ -220,7 +220,7 @@ public Q_SLOTS:
     virtual SKGError sendMessage(const QString& iMessage, bool iPopup = true);
 
     /**
-     * Get message attached to a current transaction.
+     * Get message attached to a transaction.
      * @param iIdTransaction the identifier of a transaction
      * @param oMessages the messages
      * @param iAll to get all message (true) or only popup message (false)
@@ -229,6 +229,14 @@ public Q_SLOTS:
      */
     virtual SKGError getMessages(int iIdTransaction, QStringList& oMessages, bool iAll = true);
 
+    /**
+     * Remove all message attached to a transaction.
+     * @param iIdTransaction the identifier of a transaction
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError removeMessages(int iIdTransaction);
+
     /**
      * Get list of direct modifications done in a transaction
      * @param iIdTransaction the identifier of a transaction
