@@ -120,20 +120,25 @@ int SKGObjectBase::getID() const
     return d->id;
 }
 
-QString SKGObjectBase::getDisplayName() const
+QString SKGObjectBase::getAttributeFromView(const QString& iView, const QString& iName) const
 {
     QString output;
 
     SKGStringListList result;
     QString wc = getWhereclauseId();
     if (wc.isEmpty()) wc = "id=" % SKGServices::intToString(d->id);
-    QString sql = "SELECT t_displayname FROM v_" % getRealTable() % "_displayname WHERE " % wc;
+    QString sql = "SELECT " % iName % " FROM " % iView % " WHERE " % wc;
     if (getDocument()) getDocument()->executeSelectSqliteOrder(sql, result);
     if (result.count() == 2) output = result.at(1).at(0);
 
     return output;
 }
 
+QString SKGObjectBase::getDisplayName() const
+{
+    return getAttributeFromView("v_" % getRealTable() % "_displayname", "t_displayname");
+}
+
 void SKGObjectBase::copyFrom(const SKGObjectBase& iObject)
 {
     d->id = iObject.d->id;
