@@ -241,6 +241,7 @@ int SKGServices::nbWorkingDays(const QDate& iFrom, const QDate& iTo)
         if (min.dayOfWeek() <= 5) ++nb;
         min = min.addDays(1);
     }
+    if (nb == 0) nb = 1;
     return nb;
 }
 
@@ -319,95 +320,97 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
     int nb = iDates.count();
     for (int i = 0; i < nb; ++i) {
 
-        QString val = iDates.at(i);
-        val = val.replace(' ', '0');
-        val = val.replace('\\', '-');
-        val = val.replace('/', '-');
-        val = val.replace('.', '-');
-        val = val.replace("'20", "-20");
-        val = val.replace("' ", "-200");
-        val = val.replace('\'', "-20");
-        val = val.replace("-9", "-199");
-        if (rx.indexIn(val) == -1) {
-            f_YYYY_MM_DD = false;
-            f_MM_DD_YY = false;
-            f_DD_MM_YY = false;
-            f_MM_DD_YYYY = false;
-            f_DD_MM_YYYY = false;
-
-            if (val.length() == 8) {
-                int left2 = SKGServices::stringToInt(val.left(2));
-                if (left2 > 12) {
-                    f_MMDDYYYY = false;
-                }
-                if (left2 > 31) {
-                    f_DDMMYYYY = false;
-                }
-
-                int mid2 = SKGServices::stringToInt(val.mid(2, 2));
-                if (mid2 > 12) {
-                    f_DDMMYYYY = false;
-                }
-                if (mid2 > 31) {
-                    f_MMDDYYYY = false;
-                }
-
-                int mid4 = SKGServices::stringToInt(val.mid(4, 2));
-                if (mid4 > 12) {
-                    f_YYYYMMDD = false;
-                }
-
-                int right2 = SKGServices::stringToInt(val.right(2));
-                if (right2 > 31) {
-                    f_YYYYMMDD = false;
-                }
-            }
-        } else {
-            f_YYYYMMDD = false;
-            f_DDMMYYYY = false;
-            f_MMDDYYYY = false;
-
-            QString v1 = rx.cap(1);
-            QString v2 = rx.cap(2);
-            QString v3 = rx.cap(3);
-
-            if (SKGServices::stringToInt(v1) > 12) {
-                f_MM_DD_YY = false;
-                f_MM_DD_YYYY = false;
-            }
-
-            if (SKGServices::stringToInt(v2) > 12) {
-                f_DD_MM_YY = false;
-                f_DD_MM_YYYY = false;
-            }
-
-            if (SKGServices::stringToInt(v1) > 31 || SKGServices::stringToInt(v2) > 31) {
-                f_MM_DD_YY = false;
-                f_MM_DD_YYYY = false;
-                f_DD_MM_YY = false;
-                f_DD_MM_YYYY = false;
-            }
-
-            if (SKGServices::stringToInt(v3) > 31) {
+        QString val = iDates.at(i).trimmed();
+        if (!val.isEmpty()) {
+            val = val.replace(' ', '0');
+            val = val.replace('\\', '-');
+            val = val.replace('/', '-');
+            val = val.replace('.', '-');
+            val = val.replace("'20", "-20");
+            val = val.replace("' ", "-200");
+            val = val.replace('\'', "-20");
+            val = val.replace("-9", "-199");
+            if (rx.indexIn(val) == -1) {
                 f_YYYY_MM_DD = false;
-            }
-
-            if (v1.length() == 4) {
                 f_MM_DD_YY = false;
                 f_DD_MM_YY = false;
                 f_MM_DD_YYYY = false;
                 f_DD_MM_YYYY = false;
+
+                if (val.length() == 8) {
+                    int left2 = SKGServices::stringToInt(val.left(2));
+                    if (left2 > 12) {
+                        f_MMDDYYYY = false;
+                    }
+                    if (left2 > 31) {
+                        f_DDMMYYYY = false;
+                    }
+
+                    int mid2 = SKGServices::stringToInt(val.mid(2, 2));
+                    if (mid2 > 12) {
+                        f_DDMMYYYY = false;
+                    }
+                    if (mid2 > 31) {
+                        f_MMDDYYYY = false;
+                    }
+
+                    int mid4 = SKGServices::stringToInt(val.mid(4, 2));
+                    if (mid4 > 12) {
+                        f_YYYYMMDD = false;
+                    }
+
+                    int right2 = SKGServices::stringToInt(val.right(2));
+                    if (right2 > 31) {
+                        f_YYYYMMDD = false;
+                    }
+                }
             } else {
-                f_YYYY_MM_DD = false;
-            }
+                f_YYYYMMDD = false;
+                f_DDMMYYYY = false;
+                f_MMDDYYYY = false;
 
-            if (v3.length() == 4) {
-                f_YYYY_MM_DD = false;
-                f_MM_DD_YY = false;
-                f_DD_MM_YY = false;
-            } else {
-                f_MM_DD_YYYY = false;
-                f_DD_MM_YYYY = false;
+                QString v1 = rx.cap(1);
+                QString v2 = rx.cap(2);
+                QString v3 = rx.cap(3);
+
+                if (SKGServices::stringToInt(v1) > 12) {
+                    f_MM_DD_YY = false;
+                    f_MM_DD_YYYY = false;
+                }
+
+                if (SKGServices::stringToInt(v2) > 12) {
+                    f_DD_MM_YY = false;
+                    f_DD_MM_YYYY = false;
+                }
+
+                if (SKGServices::stringToInt(v1) > 31 || SKGServices::stringToInt(v2) > 31) {
+                    f_MM_DD_YY = false;
+                    f_MM_DD_YYYY = false;
+                    f_DD_MM_YY = false;
+                    f_DD_MM_YYYY = false;
+                }
+
+                if (SKGServices::stringToInt(v3) > 31) {
+                    f_YYYY_MM_DD = false;
+                }
+
+                if (v1.length() == 4) {
+                    f_MM_DD_YY = false;
+                    f_DD_MM_YY = false;
+                    f_MM_DD_YYYY = false;
+                    f_DD_MM_YYYY = false;
+                } else {
+                    //To be more permissive and support mix of date: f_YYYY_MM_DD = false;
+                }
+
+                if (v3.length() == 4) {
+                    f_YYYY_MM_DD = false;
+                    f_MM_DD_YY = false;
+                    f_DD_MM_YY = false;
+                } else {
+                    //To be more permissive and support mix of date: f_MM_DD_YYYY = false;
+                    //To be more permissive and support mix of date: f_DD_MM_YYYY = false;
+                }
             }
         }
     }
@@ -584,31 +587,53 @@ QString SKGServices::getRealTable(const QString& iTable)
     return output;
 }
 
-SKGError SKGServices::download(const KUrl& iSourceUrl, QString& oStream)
+SKGError SKGServices::downloadToStream(const KUrl& iSourceUrl, QByteArray& oStream)
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGServices::downloadToStream", err);
+    QString tmpFile;
+    err = download(iSourceUrl, tmpFile);
+    if (!err) {
+        //Open file
+        QFile file(tmpFile);
+        if (!file.open(QIODevice::ReadOnly)) {
+            err.setReturnCode(ERR_FAIL);
+            err.setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
+        } else {
+            oStream = file.readAll();
+
+            //close file
+            file.close();
+        }
+        QFile(tmpFile).remove();
+    }
+    return err;
+}
+
+SKGError SKGServices::download(const KUrl& iSourceUrl, QString& oTemporaryFile)
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGServices::download", err);
     QTemporaryFile tmpFile;
+    tmpFile.setAutoRemove(false);
     if (tmpFile.open()) {
-        KIO::Job* getJob = KIO::file_copy(iSourceUrl, KUrl(KUrl::fromLocalFile(tmpFile.fileName())), -1, KIO::Overwrite | KIO::HideProgressInfo);
+        err = upload(iSourceUrl, KUrl::fromLocalFile(tmpFile.fileName()));
+        if (!err) oTemporaryFile = tmpFile.fileName();
+    }
+    return err;
+}
+
+SKGError SKGServices::upload(const KUrl& iSourceUrl, const KUrl& iDescUrl)
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGServices::upload", err);
+    if (iDescUrl != iSourceUrl) {
+        KIO::Job* getJob = KIO::file_copy(iSourceUrl, iDescUrl, -1, KIO::Overwrite | KIO::HideProgressInfo);
         //getJob->ui()->setWindow(window);
         if (!KIO::NetAccess::synchronousRun(getJob, 0)) {
             err.setReturnCode(ERR_ABORT);
             err.setMessage(getJob->errorString());
-        } else {
-            //Open file
-            QFile file(tmpFile.fileName());
-            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                err.setReturnCode(ERR_FAIL);
-                err.setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile.fileName()));
-            } else {
-                oStream = file.readAll();
-
-                //close file
-                file.close();
-            }
         }
-        tmpFile.remove();
     }
     return err;
 }
@@ -644,68 +669,60 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                     iEncrypt ? QCA::Encode : QCA::Decode,
                     key, iv);
 
-        QString iFileSourceTmp;
-        if (!KIO::NetAccess::download(KUrl(iFileSource), iFileSourceTmp, NULL)) err = SKGError(ERR_FAIL, KIO::NetAccess::lastErrorString());
-
+        QByteArray input;
+        err = downloadToStream(KUrl(iFileSource), input);
         if (!err) {
-            QFile fileInput(iFileSourceTmp);
-            if (!fileInput.open(QIODevice::ReadOnly)) err = SKGError(ERR_INVALIDARG, i18nc("Error message: Opening a file failed", "Open file '%1' failed", iFileSource));
-            else {
-                //Read document
-                QByteArray input = fileInput.readAll();
-                QByteArray h = (iHeaderFile % (!cipher ? "_DECRYPTED-" : "_ENCRYPTED-")).toLatin1();
-                //BUG 249955 vvv
-                if (!cipher && input.startsWith(QByteArray((iHeaderFile % "_ENCRYPTED-").toLatin1()))) err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
-                //BUG 249955 ^^^
-                if (!iEncrypt && h.count() && input.startsWith(h)) input = input.right(input.length() - h.length());
+            //Read document
+            QByteArray h = (iHeaderFile % (!cipher ? "_DECRYPTED-" : "_ENCRYPTED-")).toLatin1();
+            //BUG 249955 vvv
+            if (!cipher && input.startsWith(QByteArray((iHeaderFile % "_ENCRYPTED-").toLatin1()))) err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
+            //BUG 249955 ^^^
+            if (!iEncrypt && h.count() && input.startsWith(h)) input = input.right(input.length() - h.length());
 
-                // we use the cipher object to encrypt the argument we passed in
-                // the result of that is returned - note that if there is less than
-                // 16 bytes (1 block), then nothing will be returned - it is buffered
-                // update() can be called as many times as required.
-                QCA::SecureArray u;
-                if (!err && cipher) {
-                    u = cipher->update(input);
+            // we use the cipher object to encrypt the argument we passed in
+            // the result of that is returned - note that if there is less than
+            // 16 bytes (1 block), then nothing will be returned - it is buffered
+            // update() can be called as many times as required.
+            QCA::SecureArray u;
+            if (!err && cipher) {
+                u = cipher->update(input);
 
-                    // We need to check if that update() call worked.
-                    if (!cipher->ok()) err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
-                }
+                // We need to check if that update() call worked.
+                if (!cipher->ok()) err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
+            }
 
-                // output the results of that stage
-                if (!err) {
-                    KSaveFile fileOutput(iFileTarget);
-                    if (!fileOutput.open()) err = SKGError(ERR_WRITEACCESS, i18nc("Error message: writing a file failed", "Write file '%1' failed", iFileTarget));
+            // output the results of that stage
+            if (!err) {
+                KSaveFile fileOutput(iFileTarget);
+                if (!fileOutput.open()) err = SKGError(ERR_WRITEACCESS, i18nc("Error message: writing a file failed", "Write file '%1' failed", iFileTarget));
+                else {
+                    //Write header
+                    if (iEncrypt && h.count()) fileOutput.write(h);
+
+                    //Write document
+                    if (!cipher) fileOutput.write(input);
                     else {
-                        //Write header
-                        if (iEncrypt && h.count()) fileOutput.write(h);
+                        fileOutput.write(u.toByteArray());
 
-                        //Write document
-                        if (!cipher) fileOutput.write(input);
-                        else {
-                            fileOutput.write(u.toByteArray());
+                        // Because we are using PKCS7 padding, we need to output the final (padded) block
+                        // Note that we should always call final() even with no padding, to clean up
+                        QCA::SecureArray f = cipher->final();
 
-                            // Because we are using PKCS7 padding, we need to output the final (padded) block
-                            // Note that we should always call final() even with no padding, to clean up
-                            QCA::SecureArray f = cipher->final();
+                        // Check if the final() call worked
+                        if (!cipher->ok()) err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
 
-                            // Check if the final() call worked
-                            if (!cipher->ok()) err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
-
-                            // and output the resulting block. The ciphertext is the results of update()
-                            // and the result of final()
-                            fileOutput.write(f.toByteArray());
-                        }
-
-                        //Close the file
-                        fileOutput.finalize();
-                        fileOutput.close();
+                        // and output the resulting block. The ciphertext is the results of update()
+                        // and the result of final()
+                        fileOutput.write(f.toByteArray());
                     }
+
+                    //Close the file
+                    fileOutput.finalize();
+                    fileOutput.close();
                 }
             }
         }
 
-        KIO::NetAccess::removeTempFile(iFileSourceTmp);
-
         delete cipher;
         cipher = NULL;
     }
@@ -871,21 +888,6 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
             err = SKGServices::executeSqliteOrders(iFromFileToMemory ? iMemoryDb : iFileDb, optimization);
         }
 
-        // Copy the triggers
-        if (!err) {
-            SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYTRIGGER", err);
-            SKGStringListList listSqlOrder;
-            err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
-                    "SELECT sql FROM sqlite_master WHERE type='trigger' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
-                    listSqlOrder);
-
-            int nb = listSqlOrder.count();
-            for (int i = 1; !err && i < nb; ++i) { //Forget header
-                QString val = listSqlOrder.at(i).at(0);
-                err = SKGServices::executeSqliteOrder((iFromFileToMemory ? iMemoryDb : iFileDb), val);
-            }
-        }
-
         // Copy the indexes
         if (!err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYINDEX", err);
@@ -916,6 +918,21 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
             }
         }
 
+        // Copy the triggers, must be done after the views
+        if (!err) {
+            SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYTRIGGER", err);
+            SKGStringListList listSqlOrder;
+            err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
+                    "SELECT sql FROM sqlite_master WHERE type='trigger' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
+                    listSqlOrder);
+
+            int nb = listSqlOrder.count();
+            for (int i = 1; !err && i < nb; ++i) { //Forget header
+                QString val = listSqlOrder.at(i).at(0);
+                err = SKGServices::executeSqliteOrder((iFromFileToMemory ? iMemoryDb : iFileDb), val);
+            }
+        }
+
         //Check if created file exists
         if (!err && !iFromFileToMemory && !QFile(dbFileName).exists()) {
             //Set error message
@@ -923,7 +940,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
             err.setMessage(i18nc("An error message: creating a file failed", "Creation file '%1' failed", dbFileName));
         }
     }
-    if (err) err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message: something failed", "%1 failed", QString("copySqliteDatabase::copySqliteDatabase()")));
+    if (err) err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message: something failed", "%1 failed", QString("SKGServices::copySqliteDatabase()")));
     return err;
 }
 
